"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
require('colors');
var chai = require("chai");
var wd = require("wd");
var chaiAsPromised = require("chai-as-promised");
chai.use(chaiAsPromised);
exports.should = chai.should();
chaiAsPromised.transferPromiseness = wd.transferPromiseness;
var element_helper_1 = require("./element-helper");
var ui_element_1 = require("./ui-element");
var utils = require("./utils");
var glob = require("glob");
var fs = require("fs");
function createAppiumDriver(runType, port, caps, isSauceLab) {
    if (isSauceLab === void 0) { isSauceLab = false; }
    var driverConfig = {
        host: "localhost",
        port: port
    };
    if (isSauceLab) {
        var sauceUser = process.env.SAUCE_USER;
        var sauceKey = process.env.SAUCE_KEY;
        if (!sauceKey || !sauceUser) {
            throw new Error("Sauce Labs Username or Access Key is missing! Check environment variables for SAUCE_USER and SAUCE_KEY !!!");
        }
        driverConfig = {
            host: "https://" + sauceUser + ":" + sauceKey + "@ondemand.saucelabs.com:443/wd/hub"
        };
    }
    var driver = wd.promiseChainRemote(driverConfig);
    configureLogging(driver);
    if (utils.appLocation) {
        caps.app = isSauceLab ? "sauce-storage:" + utils.appLocation : utils.appLocation;
    }
    else if (!caps.app) {
        console.log("Getting caps.app!");
        caps.app = getAppPath(caps.platformName.toLowerCase(), runType.toLowerCase());
    }
    utils.log("Creating driver!");
    return new AppiumDriver(driver.init(caps), runType, port, caps, false);
}
exports.createAppiumDriver = createAppiumDriver;
function configureLogging(driver) {
    driver.on("status", function (info) {
        utils.log(info.cyan);
    });
    driver.on("command", function (meth, path, data) {
        utils.log(" > " + meth.yellow + path.grey + " " + (data || ""));
    });
    driver.on("http", function (meth, path, data) {
        utils.log(" > " + meth.magenta + path + " " + (data || "").grey);
    });
}
;
function getAppPath(platform, runType) {
    if (platform.includes("android")) {
        var apks = glob.sync("platforms/android/build/outputs/apk/*.apk").filter(function (file) { return file.indexOf("unaligned") < 0; });
        return apks[0];
    }
    else if (platform.includes("ios")) {
        if (runType.includes("sim")) {
            var simulatorApps = glob.sync("platforms/ios/build/emulator/**/*.app");
            return simulatorApps[0];
        }
        else if (runType.includes("device")) {
            var deviceApps = glob.sync("platforms/ios/build/device/**/*.ipa");
            return deviceApps[0];
        }
    }
    else {
        throw new Error("No 'app' capability provided and incorrect 'runType' convention used: " + runType +
            ". In order to automatically search and locate app package please use 'android','ios-device','ios-simulator' in your 'runType' option. E.g --runType android23, --runType ios-simulator10iPhone6");
    }
}
;
var AppiumDriver = (function () {
    function AppiumDriver(_driver, _runType, _port, caps, _isSauceLab, _capsLocation) {
        if (_isSauceLab === void 0) { _isSauceLab = false; }
        this._driver = _driver;
        this._runType = _runType;
        this._port = _port;
        this.caps = caps;
        this._isSauceLab = _isSauceLab;
        this._capsLocation = _capsLocation;
        this.elementHelper = new element_helper_1.ElementHelper(this.caps.platformName.toLowerCase(), this.caps.platformVersion.toLowerCase());
    }
    Object.defineProperty(AppiumDriver.prototype, "capabilities", {
        get: function () {
            return this.caps;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AppiumDriver.prototype, "platformName", {
        get: function () {
            return this.caps.platformName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AppiumDriver.prototype, "platformVesrion", {
        get: function () {
            return this.caps.platformVesrion;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AppiumDriver.prototype, "driver", {
        get: function () {
            return this._driver;
        },
        enumerable: true,
        configurable: true
    });
    AppiumDriver.prototype.navBack = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this._driver.back()];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    AppiumDriver.prototype.findElementByXPath = function (xPath, waitForElement) {
        if (waitForElement === void 0) { waitForElement = AppiumDriver.defaultWaitTime; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _a;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = ui_element_1.UIElement.bind;
                        return [4 /*yield*/, this._driver.waitForElementByXPath(xPath, waitForElement)];
                    case 1: return [2 /*return*/, new (_a.apply(ui_element_1.UIElement, [void 0, _b.sent()]))()];
                }
            });
        });
    };
    AppiumDriver.prototype.findElementsByXPath = function (xPath, waitForElement) {
        if (waitForElement === void 0) { waitForElement = AppiumDriver.defaultWaitTime; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this._driver.waitForElementsByXPath(xPath, waitForElement)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    AppiumDriver.prototype.findElementByText = function (text, match, waitForElement) {
        if (match === void 0) { match = 0 /* exact */; }
        if (waitForElement === void 0) { waitForElement = AppiumDriver.defaultWaitTime; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var shouldMatch;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        shouldMatch = match === 0 /* exact */ ? true : false;
                        return [4 /*yield*/, this.findElementByXPath(this.elementHelper.getXPathByText(text, shouldMatch), waitForElement)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    AppiumDriver.prototype.findElementsByText = function (text, match, waitForElement) {
        if (match === void 0) { match = 0 /* exact */; }
        if (waitForElement === void 0) { waitForElement = AppiumDriver.defaultWaitTime; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var shouldMatch;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        shouldMatch = match === 0 /* exact */ ? true : false;
                        return [4 /*yield*/, this.findElementsByXPath(this.elementHelper.getXPathByText(text, shouldMatch), waitForElement)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    AppiumDriver.prototype.findElementsByClassName = function (className, waitForElement) {
        if (waitForElement === void 0) { waitForElement = AppiumDriver.defaultWaitTime; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var fullClassName;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        fullClassName = this.elementHelper.getElementClass(className);
                        return [4 /*yield*/, this._driver.waitForElementsByClassName(fullClassName, waitForElement)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    AppiumDriver.prototype.takeScreenshot = function (fileName) {
        return this._driver.takeScreenshot().then(function (image, err) {
            fs.writeFile(fileName, image, 'base64', function (err) {
                console.log(err);
            });
        });
    };
    AppiumDriver.prototype.quit = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        console.log("Killing driver");
                        return [4 /*yield*/, this._driver.quit()];
                    case 1:
                        _a.sent();
                        console.log("Driver is dead");
                        return [2 /*return*/];
                }
            });
        });
    };
    AppiumDriver.defaultWaitTime = 5000;
    return AppiumDriver;
}());
exports.AppiumDriver = AppiumDriver;
//# sourceMappingURL=appium-driver.js.map