"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var child_process = require("child_process");
var fs = require("fs");
var utils = require("./utils");
var AppiumServer = (function () {
    function AppiumServer() {
        this.resolveAppiumDependency();
    }
    Object.defineProperty(AppiumServer.prototype, "port", {
        get: function () {
            return this._port;
        },
        set: function (port) {
            this._port = port;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AppiumServer.prototype, "runType", {
        get: function () {
            return this._runType;
        },
        set: function (runType) {
            this._runType = runType;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AppiumServer.prototype, "server", {
        get: function () {
            return this._server;
        },
        enumerable: true,
        configurable: true
    });
    AppiumServer.prototype.start = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                utils.log("Starting server...");
                this._server = child_process.spawn(this._appium, ["-p", this._port.toString()], {
                    shell: true,
                    detached: false
                });
                return [2 /*return*/, utils.waitForOutput(this._server, /listener started/, 60000)];
            });
        });
    };
    AppiumServer.prototype.stop = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this._server.on("close", function (code, signal) {
                utils.log("Appium terminated due signal: " + signal + " and code: " + code);
                resolve();
            });
            utils.log("Stopping server...");
            _this._server.kill("SIGINT");
        });
    };
    // Resolve appium dependency
    AppiumServer.prototype.resolveAppiumDependency = function () {
        var projectDir = utils.projectDir();
        var pluginBinary = utils.pluginBinary();
        var projectBinary = utils.projectBinary();
        var pluginRoot = utils.pluginRoot();
        var appium = process.platform === "win32" ? "appium.cmd" : "appium";
        var pluginAppiumBinary = utils.resolve(pluginBinary, appium);
        var projectAppiumBinary = utils.resolve(projectBinary, appium);
        if (fs.existsSync(pluginAppiumBinary)) {
            utils.log("Using plugin-local Appium binary.");
            appium = pluginAppiumBinary;
        }
        else if (fs.existsSync(projectAppiumBinary)) {
            utils.log("Using project-local Appium binary.");
            appium = projectAppiumBinary;
        }
        else {
            utils.log("Using global Appium binary.");
        }
        this._appium = appium;
    };
    return AppiumServer;
}());
exports.AppiumServer = AppiumServer;
//# sourceMappingURL=appium-server.js.map