"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var fs = require("fs");
var utils = require("./utils");
var projectDir = utils.projectDir();
function resolveCapabilities(capsLocation, runType) {
    var caps;
    var customCapabilitiesConfigs = searchCustomCapabilities(capsLocation);
    if (customCapabilitiesConfigs) {
        var customCapabilities = JSON.parse(customCapabilitiesConfigs);
        utils.log(customCapabilities);
        caps = customCapabilities[runType];
        if (!caps) {
            throw new Error("Not suitable runType!!!");
        }
    }
    else {
        throw new Error("No capabilities found!!!");
    }
    return caps;
}
exports.resolveCapabilities = resolveCapabilities;
function searchCustomCapabilities(capabilitiesLocation) {
    // resolve capabilites if exist
    if (utils.fileExists(capabilitiesLocation) && utils.isFile(capabilitiesLocation)) {
        return setCustomCapabilities(capabilitiesLocation);
    }
    // search for default capabilites
    var customCapabilitiesLocation = utils.searchFiles(projectDir, utils.capabilitiesName)[0];
    if (utils.fileExists(customCapabilitiesLocation)) {
        return setCustomCapabilities(customCapabilitiesLocation);
    }
    // search in parent folder for capabilities
    var appParentFolder = path.dirname(projectDir);
    customCapabilitiesLocation = utils.searchFiles(appParentFolder, utils.capabilitiesName, true)[0];
    if (utils.fileExists(customCapabilitiesLocation)) {
        return setCustomCapabilities(customCapabilitiesLocation);
    }
    else {
        // search for capabilities recursive 
        var cap = utils.searchFiles(appParentFolder, utils.capabilitiesName, true)[0];
        if (cap) {
            setCustomCapabilities(cap);
        }
    }
    throw Error("No capabilities found!!!");
}
exports.searchCustomCapabilities = searchCustomCapabilities;
function setCustomCapabilities(appiumCapabilitiesLocation) {
    var file = fs.readFileSync(appiumCapabilitiesLocation);
    process.env.APPIUM_CAPABILITIES = file;
    utils.log("Custom capabilities found at: " + appiumCapabilitiesLocation);
    return file;
}
//# sourceMappingURL=capabilities-helper.js.map