"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path = require("path");
var yargs = require("yargs");
var utils = require("./utils");
var appium_server_1 = require("./appium-server");
var capabilities_helper_1 = require("./capabilities-helper");
var element_helper_1 = require("./element-helper");
var appium_driver_1 = require("./appium-driver");
var portastic = require("portastic");
var appium_driver_2 = require("./appium-driver");
exports.AppiumDriver = appium_driver_2.AppiumDriver;
tslib_1.__exportStar(require("./search-options"), exports);
// TODO: Update variables consider also this from utils. 
var config = (function () {
    var options = yargs
        .option("runType", { describe: "Path to excute command.", type: "string", default: null })
        .option("testFolder", { describe: "e2e test folder name", default: "e2e", type: "string" })
        .option("capabilities", { describe: "Capabilities", type: "string" })
        .option("sauceLab", { describe: "SauceLab", default: false, type: "boolean" })
        .option("port", { alias: "p", describe: "Execution port", type: "string" })
        .option("verbose", { alias: "v", describe: "Log actions", default: false, type: "boolean" })
        .help()
        .argv;
    var config = {
        executionPath: options.path,
        port: options.port,
        loglevel: options.verbose,
        testFolder: options.testFolder,
        runType: options.runType || process.env.npm_config_runType,
        capabilities: options.capabilities || path.join(process.cwd(), options.testFolder, "config", utils.capabilitiesName),
        isSauceLab: options.sauceLab
    };
    return config;
})();
var executionPath = config.executionPath, loglevel = config.loglevel, capabilities = config.capabilities, testFolder = config.testFolder, runType = config.runType, isSauceLab = config.isSauceLab;
var server = new appium_server_1.AppiumServer();
function startServer(port) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    server.port = port || config.port;
                    if (!!port) return [3 /*break*/, 2];
                    _a = server;
                    return [4 /*yield*/, portastic.find({ min: 8600, max: 9080 })];
                case 1:
                    _a.port = (_b.sent())[0];
                    _b.label = 2;
                case 2: return [4 /*yield*/, server.start()];
                case 3: return [2 /*return*/, _b.sent()];
            }
        });
    });
}
exports.startServer = startServer;
;
function stopServer() {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, server.stop()];
                case 1: return [2 /*return*/, _a.sent()];
            }
        });
    });
}
exports.stopServer = stopServer;
;
var caps = capabilities_helper_1.resolveCapabilities(capabilities, runType);
function createDriver() {
    if (!caps) {
        throw new Error("Provided path to appium capabilities is not correct!");
    }
    if (!runType) {
        throw new Error("--runType is missing! Make sure it is provided correctly! It is used to parse the configuration for appium driver!");
    }
    return appium_driver_1.createAppiumDriver(runType, server.port, caps, isSauceLab);
}
exports.createDriver = createDriver;
;
function elementHelper() {
    return new element_helper_1.ElementHelper(this.caps.platformName.toLowerCase(), this.caps.platformVersion.toLowerCase());
}
exports.elementHelper = elementHelper;
process.on("exit", function (server) { return utils.shutdown(server); });
process.on('uncaughtException', function (server) { return utils.shutdown(server); });
//# sourceMappingURL=index.js.map